@@ -1,7 +1,7 @@
 from photoshop._core import Photoshop
-from photoshop.artlayer import ArtLayer
-from photoshop.layers import Layers
 from photoshop.layerSet import LayerSet
+from photoshop.errors import PhotoshopPythonAPIError
+
 
 class LayerSets(Photoshop):
     def __init__(self, parent):
@@ -11,7 +11,7 @@ class LayerSets(Photoshop):
         return self.length
 
     def __getitem__(self, key):
-        return ArtLayer(self._layerSets[key])
+        return LayerSet(self._layerSets[key])
 
     @property
     def _layerSets(self):
@@ -22,12 +22,14 @@ class LayerSets(Photoshop):
         return len(self._layerSets)
 
     def add(self):
-        self.app.add()
+        return LayerSet(self.app.add())
 
     def item(self, index):
         return LayerSet(self.app.item(index))
 
     def getByName(self, name):
-        for layer in self._layerSets:
+        for layer in self.app:
             if name == layer.name:
-                return LayerSet(layer.layers)
+                return LayerSet(layer)
+        raise PhotoshopPythonAPIError(f'Could not find a LayerSet named '
+                                      f'"{name}"')
